yu-iskw
02/01/2024, 4:03 AM03:19:52 Running 1 on-run-end hook
03:43:48 1 of 1 START hook: elementary.on-run-end.0 ..................................... [RUN]
03:43:48 1 of 1 OK hook: elementary.on-run-end.0 ........................................ [OK in 0.00s]Adam
02/01/2024, 10:19 AMNoam Moskowitz
02/01/2024, 10:26 AMyu-iskw
02/01/2024, 12:06 PM# dbt_project.yml
vars:
disable_run_results: "{{ target.name not in ['prod','analytics'] }}"
disable_tests_results: "{{ target.name != 'prod' }}"
disable_dbt_artifacts_autoupload: "{{ target.name != 'prod' }}"
disable_dbt_invocation_autoupload: "{{ target.name != 'prod' }}"
I’m trying the properties, as macros related to them took a long time in our case. However, that would be good, if disable_dbt_artifacts_autoupload doesn’t affect to use the community edition of Elementary, not Elementary Cloud.
upload_artifacts_method: replace
disable_dbt_columns_autoupload: trueyu-iskw
02/05/2024, 5:50 AMdisable_dbt_artifacts_autoupload: true , though I don’t completely understand the side effect on Elementary reports. Now, it doesn’t take time to run the run-on-end hook of Elementary.Ofek Weiss
02/05/2024, 12:50 PMdbt.log of these long runs?Brian Waligorski
02/12/2024, 6:50 PMdbt-bigquery==1.7.4 and we recently upgraded our package from elementary-data/elementary==0.11.2 to elementary-data/elementary==0.13.2. On 0.11.2, the post-run hook took less than a second:
00:01:44
00:01:44 Running 1 on-run-start hook
00:01:44 1 of 1 START hook: elementary.on-run-start.0 ................................... [RUN]
00:01:44 1 of 1 OK hook: elementary.on-run-start.0 ...................................... [OK in 0.00s]
00:01:44
On 0.13.2, the post-run hook takes nearly a minute (note the leftmost timestamps, rather than the [OK in 0.00s] message:
00:34:59
00:34:59 Running 1 on-run-end hook
00:35:52 1 of 1 START hook: elementary.on-run-end.0 ..................................... [RUN]
00:35:52 1 of 1 OK hook: elementary.on-run-end.0 ........................................ [OK in 0.00s]
00:35:52
Looking at our BigQuery audit logs, it appears that the Elementary on-run-end hook is inserting into the following tables in our Elementary dataset (I’ve included the job duration in parentheses):
• data_monitoring_metrics (1 sec)
• dbt_artifacts_hashes (1 sec)
• 2 instances of a test that runs SELECT metadata_hash from dbt_tests WHERE 1=0 🤷 (1 sec)
• 2 instances of inserts into dbt_tests__tmp_* (1 sec)
• dbt_tests (5 sec)
• dbt_run_results (1 sec)
• elementary_test_results (1 sec)
• dbt_invocations (1 sec)
So, 12 seconds of BigQuery job time in total.Noa Kurman
02/13/2024, 8:08 AMBrian Waligorski
02/13/2024, 3:23 PMdbt-bigquery==1.7.4
• elementary-data/elementary==0.13.2
We have a hybrid dbt cloud/dbt-core architecture, and we’ve observed the on-run-end slowdowns on both core and cloudyu-iskw
02/15/2024, 11:03 PMYaoni
07/30/2024, 3:20 AMdbt-snowflake==1.4.4
- package: elementary-data/elementary
version: 0.13.0Noam Moskowitz
10/08/2024, 1:41 PMMar
10/29/2024, 3:04 AMJonas Subel
11/28/2024, 11:25 AMvars:
disable_dbt_invocation_autoupload: "{{ target.name != 'prod' }}"
shouldn't really work, right?